**Methods**

**Plant Genome Survey and motif extraction.**
A broad survey of the translation initiation motifs from both the TAIR10 _Arabidopsis thaliana_ genome build \cite{eyer_Muller_Ploetz_et_al__2007} and the IRGSP 1.0 Japanese Rice Genome \cite{rtz_Tanaka_Wu_Zhou_et_al__2013} was carried out.   In order to capture translation initiation motifs as well as possible leader peptide sequences, the Gene description GFF files were used to extract the 25 bases before and 18 bases after the start codon of each gene for each genome build.  The terms "CDS" or "mRNA" were used to extract protein coding regions. With the data from the rice genome, we were unable to separate coding sequences in all three possible reading frames, therefore we excluded codign sequences that did not initiate with the canonical "ATG" start codon.

**Chloroplast survey and motif extraction.**
Because of the small number of genes in the chloroplast, a broad collection of motifs were also extracted for chloroplasts. The GenBank chromosome sequences were scraped from the Choloroplast DB webpage \cite{Cui_2006} and used to extract motifs using BioPython \cite{cock2009biopython}.  This yielded 11810 initiation motifs from 109 organisms, which gave good consistency in the start codon with translation initiation generally occurring 8 nucleotides downstream of the ribosome binding site, as expected. 

**Transcriptome Data**
As we could find no publicly available matched proteome / transcriptome datasets, we obtained 10 arrays each from arabidopsis leaf and rice leaf.  All replicate arrays for noon-time leaf expression in adult plants were obtained from Gene Expression Omnibus \cite{ippy_Sherman_Holko_et_al__2012}, via GEOSearch \cite{vis_Stephens_Meltzer_Chen_2008}. 

Table [1] lists the data sets that were chosen in the Workshop session.  

| Tables        | Are           | Cool  |
| ------------- |:-------------:| -----:|
| col 3 is      | right-aligned | $1600 |
| col 2 is      | centered      |   $12 |
| zebra stripes | are neat      |    $1 |

Overall 10 arrays including replicates of four separate measurements were downloaded as Affymetrix Arabidopsis Genome ATH1 and Rice Genome Array CEL files.  These were scaled using the MAS5 algorithm \cite{lim2007comparative} using the 'affy' Biocoductor library \cite{affy2004} in R \cite{R_Core_Team_2013}.  The resulting data frame was reduced to mean, median and standard deviation estimates for each probe set for Rice and Arabidopsis each. The results were that the mean measurement standard deviation was 71 % and the median differed by 19% from the mean, indicating a reasonable sample variance that was satisfactory where doubling of intensities is considered significant.

**Proteome Data**
The Rice Proteome Project has a comprehensive set of quantitative proteome estimates from 2D SDS PAGE gel including different stages of the plant growth, portions of the plant as well as an organelle survey.  Quantitation from gel densitometry, MASCOT scores and uniprot associations were downloaded as tables \cite{i_Tozawa_Yoshinaga_et_al__2004}.

Only a few hundred measurements were found from multiple sources for Arabidopsis, which did not cover the organelles explicitly and less than 10% of the known leaf proteome. As the data proved to be inadequate for this study, the Arabidopsis survey had to be set aside. 

Uniprot identifiers were mapped to rice probe set identifiers. Many of the Uniprot identifiers were directly mappable to probe set (236 out of 554 identifiers: split among 123 chloroplast, 235 mature leaf, and 196 seedling leaf probes), using the Rice Coexpression Database \cite{Sato_2013}. The remaining Uniprot identifiers were manually mapped, BLASTP searching Uniprot sequence against the _Oryza sativa_ Nipponbare reference genome \cite{Kawahara_2013}.   

**Translation Initiation Estimation for motifs**
The interrelationship between Rice Gene, Protein in the Proteome set, and the MicroArray Probe set required several data sources.  The Probe Set Annotation data for the Rice IVT Expression Array was extracted from the Probe Set Annotation CSV file provided by Affymetrix \cite{Liu_2003}.  Because UniProt accessions drift over time, the Rice Proteome, which was generated circa 2004, had no protein accessions which were currently in uniprot.  Data relationships to gene names and probe sets were assembled through multiple processes.  Reviewing archival Rice Genome Array annotations were able to find about 50% of the probe set mappings we needed and the rest were recovered manually by searches of uniprot.org and if necessary, BLAST alignment of nucleotide sequences against the Rice Genome at MSU.edu.

For genes which had proteome protein concentration estimates, the translational coefficient, \(\Theta\), for a given gene was estimated as the ratio of the protein to the mean RNA concentration as estimated by the microarray intensity.

\(\Theta\) = [Protein]/[mRNA] {1}

In order to reduce the influence of outliers, the mRNA concentration was takes as the median of the microarray values from the 10 data sets.  This reduced the range of the values by 2 logs compared to taking the mean microarray probe set intensity. 
